# Plume

A light weight blog that's federated via ActivityPub. It's a blog that can talk to the ActivityPub network for comments and sharing.

## Inspiration / Further Reading

- [https://joinplu.me/](https://joinplu.me/)
- [https://github.com/Plume-org/Plume](https://github.com/Plume-org/Plume)

## Prep Install

``` bash

# Prep
mkdir -p /var/plume
touch /var/plume/.env
cd /var/plume

# Ensure we pull the right plume image for the board
ARCH=`arch`
if [ $ARCH == "aarch64" ]
then
    ARCH="arm64v8"
else
    ARCH="arm32v7"
fi

# Run a temporary plume container for setup
docker run --rm -it --net docker-private \
    -v /var/plume/static/media:/app/static/media \
    -v /var/plume/.env:/app/.env \
    -v /var/plume/search_index:/app/search_index \
    registry.lollipopcloud.solutions/$ARCH/plume:latest \
    /bin/bash

# Run the plume setup inside the temporary container (answer all prompts accordingly)
diesel database setup --migration-dir migrations/postgres/
plm instance new
plm users new --admin
plm search init

```

## Install / Run

``` bash

cat > /root/plume.sh <<EOF
#!/bin/bash

ARCH=\`arch\`
if [ \$ARCH == "aarch64" ]
then
    ARCH="arm64v8"
else
    ARCH="arm32v7"
fi

docker pull registry.lollipopcloud.solutions/\$ARCH/plume:latest
docker rm -f plume

docker run \\
    --name plume \\
    --restart unless-stopped \\
    --net docker-private \\
    --ip 172.30.12.21 \\
    -e TZ=UTC \\
    -e DEBUG=1 \\
    -v /var/plume/static/media:/app/static/media \\
    -v /var/plume/.env:/app/.env \\
    -v /var/plume/search_index:/app/search_index \\
    registry.lollipopcloud.solutions/\$ARCH/plume:latest

EOF

```

Simply execute ```/root/plume.sh``` to update/run Plume.
